@@ -1,7 +1,7 @@
 package Data::Unixish::subsort;
 
-our $DATE = '2015-11-22'; # DATE
-our $VERSION = '1.52'; # VERSION
+our $DATE = '2016-03-02'; # DATE
+our $VERSION = '1.53'; # VERSION
 
 use 5.010;
 use strict;
@@ -20,7 +20,7 @@ $SPEC{subsort} = {
         %common_args,
         routine => {
             summary => 'Sort::Sub routine name',
-            schema=>['str*'],
+            schema=>['str*', match=>qr/\A\w+\z/],
             req => 1,
             pos => 0,
         },
@@ -38,8 +38,6 @@ $SPEC{subsort} = {
     tags => [qw/ordering/],
 };
 sub subsort {
-    require Sort::Sub;
-
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
     my $routine = $args{routine} or return [400, "Please specify routine"];
@@ -55,11 +53,11 @@ sub subsort {
         push @buf, $item;
     }
 
-    Sort::Sub->import("$args{routine}<".
-                          ($ci ? "i":"").
-                          ($reverse ? "r":"").
-                          ">");
-    @buf = sort {&{"$routine"}} @buf;
+    require "Sort/Sub/$routine.pm";
+    my $gen_sorter = \&{"Sort::Sub::$routine\::gen_sorter"};
+    my $sorter = $gen_sorter->($reverse, $ci);
+
+    @buf = sort {$sorter->($a, $b)} @buf;
 
     push @$out, $_ for @buf;
 
@@ -81,7 +79,7 @@ Data::Unixish::subsort - Sort items using Sort::Sub routine
 
 =head1 VERSION
 
-This document describes version 1.52 of Data::Unixish::subsort (from Perl distribution Data-Unixish), released on 2015-11-22.
+This document describes version 1.53 of Data::Unixish::subsort (from Perl distribution Data-Unixish), released on 2016-03-02.
 
 =head1 SYNOPSIS
 
@@ -98,14 +96,6 @@ In command line:
  t2
  t10
 
-=head1 SEE ALSO
-
-L<subsort> (from L<App::subsort>)
-
-sort(1)
-
-L<psort> (from L<App::psort>)
-
 =head1 FUNCTIONS
 
 
@@ -113,7 +103,7 @@ L<psort> (from L<App::psort>)
 
 Sort items using Sort::Sub routine.
 
-This function is not exportable.
+This function is not exported.
 
 Arguments ('*' denotes required arguments):
 
@@ -158,7 +148,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Data-Unixi
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Data-Unixish>.
+Source repository is at L<https://github.com/perlancar/perl-Data-Unixish>.
 
 =head1 BUGS
 
@@ -168,13 +158,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<subsort> (from L<App::subsort>)
+
+sort(1)
+
+L<psort> (from L<App::psort>)
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
